#!/bin/sh
# $Id$
#
# This script can be used to start WebLogic Server. This script ensures 
# that the server is started using the config.xml file found in this 
# directory and that the CLASSPATH is set correctly. This script contains 
# the following variables: 
# 
# WL_HOME        - The root directory of your WebLogic Server 
#                  installation
# JAVA_HOME      - Determines the version of Java used to start  
#                  WebLogic Server. This variable must point to the 
#                  root directory of a JDK installation and will be set 
#                  for you by the WebLogic Server installer.
#                  See the WebLogic platform support 
#                  page (http://e-docs.bea.com/wls/platforms/index.html)
#                  for an up-to-date list of supported JVMs on your platform. 
# JAVA_OPTIONS   - Java command-line options for running the server.
# 
# jDriver for Oracle users: This script assumes that native libraries 
# required for jDriver for Oracle have been installed in the proper 
# location and that your system LD_LIBRARY_PATH variable has been set appropriately. 
# Also note that this script default to the oci816_8 version of the 
# shared libraries. If this is not the version you need, please adjust the 
# LD_LIBRARY_PATH variable accordingly. 
#
# For additional information, refer to Installing and Setting up WebLogic 
# Server (http://e-docs.bea.com/wls/docs60/install/index.html). 


# Set user-defined variables. 
JAVA_HOME=/opt/jdk1.3
WL_HOME=/opt/weblo6/wlserver6.0

JAVA_OPTIONS="-ms64m -mx64m"
SERVER_CLASSES=/home/ens/sfrenot/weblo6u/config/mydomain/serverclasses/

# Check that script is being run from the appropriate directory
if [ ! -f config.xml ]; then
  echo "startWeblogic.sh: must be run from the config/mydomain directory." 1>&2

# Check for classes
elif [ ! -f $WL_HOME/lib/weblogic.jar ]; then
  echo "The weblogic.jar file was not found in directory $WL_HOME/lib." 1>&2

# Check for JDK
elif [ ! -f $JAVA_HOME/bin/java ]; then
  echo "The JDK wasn't found in directory $JAVA_HOME." 1>&2

else
cd ../..

# Grab some file descriptors.
maxfiles=`ulimit -H -n`
if [ ! $? -a "$maxfiles" != 1024 ]; then
  if [ "$maxfiles" = "unlimited" ]; then
    maxfiles=1025
  fi
  if [ "$maxfiles" -lt 1024 ]; then
    ulimit -n $maxfiles
  else
    ulimit -n 1024
  fi
fi

# Figure out how to use our shared libraries
case `uname -s` in
AIX)
  if [ -n "$LIBPATH" ]; then
    LIBPATH=$LIBPATH:$WL_HOME/lib/aix
  else
    LIBPATH=$WL_HOME/lib/aix
  fi
  export LIB_PATH
  echo "LIBPATH=$LIBPATH"
;;
HP-UX)
  if expr "`uname -r`" : "..11..." > /dev/null 2>&1; then
    hpsubdir=hpux11
  elif expr "`uname -r`" : "..10..." > /dev/null 2>&1; then 
    hpsubdir=hpux10
  fi

  chmod a+x `find $WL_HOME/lib/$hpsubdir -name "*.sl" -print`
 
  if [ -n "$SHLIB_PATH" ]; then
    SHLIB_PATH=$SHLIB_PATH:$WL_HOME/lib/$hpsubdir
  else
    SHLIB_PATH=$WL_HOME/lib/$hpsubdir
  fi
  export SHLIB_PATH
  echo "SHLIB_PATH=$SHLIB_PATH"
  JAVA_OPTIONS="-classic $JAVA_OPTIONS"
;;
IRIX)
  if [ -n "$LD_LIBRARY_PATH" ]; then
    LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$WL_HOME/lib/irix
  else
    LD_LIBRARY_PATH=$WL_HOME/lib/irix
  fi
  export LD_LIBRARY_PATH
  echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"
;;
LINUX|Linux)
  if [ -n "$LD_LIBRARY_PATH" ]; then
    LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$WL_HOME/lib/linux
  else
    LD_LIBRARY_PATH=$WL_HOME/lib/linux
  fi
  export LD_LIBRARY_PATH
  echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"
;;
OSF1)
  if [ -n "$_RLD_LIST" ]; then
    _RLD_LIST=$_RLD_LIST:$WL_HOME/lib/tru64unix
  else
    _RLD_LIST=$WL_HOME/lib/tru64unix
  fi
  export _RLD_LIST
  echo "_RLD_LIST=$_RLD_LIST"
;;
SunOS)
  if [ -n "$LD_LIBRARY_PATH" ]; then
    LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$WL_HOME/lib/solaris:$WL_HOME/lib/solaris/oci816_8
  else
    LD_LIBRARY_PATH=$WL_HOME/lib/solaris:$WL_HOME/lib/solaris/oci816_8
  fi
  export LD_LIBRARY_PATH
  echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"
  JAVA_OPTIONS="-hotspot $JAVA_OPTIONS"
;;
*)
  echo "$0: Don't know how to set the shared library path for `uname -s`.  "
esac

CLASSPATH=$WL_HOME:$WL_HOME/lib/weblogic_sp.jar:$WL_HOME/lib/weblogic.jar:$SERVER_CLASSES

PATH=$WL_HOME/bin:$JAVA_HOME/jre/bin:$JAVA_HOME/bin:$PATH

echo $CLASSPATH

java $JAVA_OPTIONS -classpath $CLASSPATH -Dweblogic.Domain=mydomain -Dweblogic.Name=monserveur -Dbea.home=/home/ens/sfrenot/weblo6u -Djava.security.policy==/opt/weblo6/wlserver6.0/lib/weblogic.policy -Dweblogic.management.password=$WLS_PW weblogic.Server

cd config/mydomain

fi
